OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soll die externe Freigabe {name} von {owner}@{remote} hinzugefügt werden?",
    "Remote share" : "Externe Freigabe",
    "Remote share password" : "Passwort für die externe Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Externe Freigabe hinzufügen",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "Couldn't establish a federated share." : "Federated-Share konnte nicht aufgebaut werden",
    "Couldn't establish a federated share, maybe the password was wrong." : "Federated-Share konnte nicht aufgebaut werden, da eventuell das Passwort falsch ist.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Anfrage zum Federated-Share war erfolgreich. Du erhälst eine Einladung. Bitte prüfe Deine Benachrichtigungen. ",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Federated-Share konnte nicht aufgebaut werden, da der Zielserver eine zu alte Version verwendet (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "Das Erstellen einer Federated Cloud Freigabe ist von diesem Server aus nicht erlaubt.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Freigabe von %1$s fehlgeschlagen, da dieses Objekt schon mit %2$s geteilt wird",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "File is already shared with %s" : "Datei wird bereits mit %s geteilt",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %1$s fehlgeschlagen, da %2$s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat.",
    "Could not find share" : "Freigabe konnte nicht gefunden werden",
    "Federated sharing" : "Federated-Sharing",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Du hast \"%3$s\" als externe Freigabe von %4$s (%1$s) empfangen (im Auftrag von %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du hast {share} als externe Freigabe von {user} empfangen (im Auftrag von {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Du hast  \"%3$s\" als externe Freigabe von %4$s (%1$s) erhalten",
    "You received {share} as a remote share from {user}" : "Du hast {share} als externe Freigabe von {user} empfangen",
    "Accept" : "Ok",
    "Decline" : "Abgelehnt",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Über meine #Nextcloud Federated-Cloud-ID teilen, siehe %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Teile mit mir über meine #Nextcloud Federated-Cloud-ID",
    "Sharing" : "Teilen",
    "Federated file sharing" : "Federated Datei-Freigabe",
    "Provide federated file sharing across servers" : "Bietet Federated Datei-Freigaben über Servergrenzen hinweg",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Adjust how people can share between servers." : "Definiere wie die Benutzer Inhalte mit anderen Servern teilen können.",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Allow users on this server to send shares to groups on other servers" : "Ermögliche Nutzern dieses Servers Freigaben an Gruppen auf anderen Servern zu senden",
    "Allow users on this server to receive group shares from other servers" : "Ermögliche Nutzern dieses Servers Gruppen-Freigaben von anderen Servern zu empfangen",
    "Search global and public address book for users" : "Globale Suche und ein öffentliches Adressbuch für Benutzer",
    "Allow users to publish their data to a global and public address book" : "Erlaube Benutzern ihre Daten an ein globales und öffentliches Adressbuch zu veröffentlichen",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kannst mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Gebe einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
    "Your Federated Cloud ID:" : "Deine Federated-Cloud-ID:",
    "Share it so your friends can share files with you:" : "Teile es, so dass Deine Freunde Dateien mit Dir teilen können:",
    "Add to your website" : "Zu Deiner Webseite hinzufügen",
    "Share with me via Nextcloud" : "Teile mit mir über Nextcloud",
    "HTML Code:" : "HTML-Code:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du hast \"%3$s\" als externe Freigabe von \"%1$s\" empfangen (im Auftrag von %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "Du hast \"%3$s\" als externe Freigabe von \"%1$s\" empfangen"
},
"nplurals=2; plural=(n != 1);");
